@@ -1,25 +1,26 @@
-from typing import Dict
+import importlib.metadata
 
-from pydantic import BaseModel, Extra
+from pydantic import BaseModel
 
 from .app import App
 
-
-__version__ = "0.1.2"
+try:
+    __version__ = importlib.metadata.version("jupyverse_api")
+except importlib.metadata.PackageNotFoundError:
+    __version__ = "unknown"
 
 
 class Singleton(type):
-    _instances: Dict = {}
+    _instances: dict = {}
 
     def __call__(cls, *args, **kwargs):
         if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
+            cls._instances[cls] = super().__call__(*args, **kwargs)
         return cls._instances[cls]
 
 
 class Config(BaseModel):
-    class Config:
-        extra = Extra.forbid
+    model_config = {"extra": "forbid"}
 
 
 class Router:
@@ -40,3 +41,6 @@ class Router:
 
     def mount(self, path: str, *args, **kwargs) -> None:
         self._app._mount(path, self._type, *args, **kwargs)
+
+    def add_middleware(self, middleware, *args, **kwargs) -> None:
+        self._app.add_middleware(middleware, *args, **kwargs)
