@@ -1,4 +1,5 @@
-from typing import Optional
+from __future__ import annotations
+
 from pydantic import BaseModel
 
 
@@ -6,8 +7,8 @@ class User(BaseModel):
     username: str = ""
     name: str = ""
     display_name: str = ""
-    initials: Optional[str] = None
-    color: Optional[str] = None
-    avatar_url: Optional[str] = None
+    initials: str | None = None
+    color: str | None = None
+    avatar_url: str | None = None
     workspace: str = "{}"
     settings: str = "{}"
